# OIDCProxyHeader

The configuration of header fields for oidc proxy to set/substitute.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**domain_substitution** | [**OIDCProxyDomainSubstitution**](OIDCProxyDomainSubstitution.md) |  | [optional] 
**header_overrides** | [**OIDCProxyHeaderOverride**](OIDCProxyHeaderOverride.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


